diskStat

package
v0.0.0-...-fd4faf2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2016 License: MIT Imports: 3 Imported by: 16

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DiskStat

type DiskStat struct {
	Id                    int64
	PartId                int64
	Device                string
	ReadsCompleted        int64
	ReadsMerged           int64
	SectorsRead           uint64
	MillisReading         int64
	WritesCompleted       int64
	WritesMerged          int64
	SectorsWrite          uint64
	MillisWriting         int64
	IoInProgress          int64
	MillisDoingIo         int64
	WeightedMillisDoingIo int64
	RecordTime            int64
	IoTotal               int64
	SectorsTotalRaw       uint64
}

func LineToStat

func LineToStat(line []string) (stat DiskStat, err error)

Simple function that takes a string and converts it to a stat TODO: Figure out better way to map string to struct

type ExtendedIoStats

type ExtendedIoStats struct {
	Device       string
	ReadsMerged  float64
	WritesMerged float64
	Writes       float64
	Reads        float64
	SectorsRead  float64
	SectorsWrite float64
	Arqsz        float64
	AvgQueueSize float64
	Await        float64
	RAwait       float64
	WAwait       float64
	Util         float64
	Svctm        float64
}

Jump to