Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var LastRawStat = make(map[string]diskStat.DiskStat)
Functions ¶
func IsPartition ¶
func TransformStat ¶
func TransformStat(channel <-chan *diskStat.DiskStat, statsOutputChannel chan *diskStat.ExtendedIoStats) (err error)
TransformStat goroutine function to transform the stats and send to the stats output channel.
Types ¶
type DiskStatDiff ¶
type DiskStatDiff struct {
Id int64
PartId int64
Device string
ReadsCompleted float64
ReadsMerged float64
SectorsRead float64
MillisReading float64
WritesCompleted float64
WritesMerged float64
SectorsWrite float64
MillisWriting float64
// IoInProgress float64 //not used and calculated diff then all others
MillisDoingIo float64
WeightedMillisDoingIo float64
RecordTime float64
IoTotal float64
SectorsTotalRaw float64
}
DiskStatDiff struct for all extended io stats storing just the difference between the current and the last.
Click to show internal directories.
Click to hide internal directories.