Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DiskStat ¶
type DiskStat struct {
Id int64
PartId int64
Device string
ReadsCompleted int64
ReadsMerged int64
SectorsRead uint64
MillisReading int64
WritesCompleted int64
WritesMerged int64
SectorsWrite uint64
MillisWriting int64
IoInProgress int64
MillisDoingIo int64
WeightedMillisDoingIo int64
RecordTime int64
IoTotal int64
SectorsTotalRaw uint64
}
func LineToStat ¶
Simple function that takes a string and converts it to a stat TODO: Figure out better way to map string to struct
Click to show internal directories.
Click to hide internal directories.